# TestPointSelector


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**configuration_id** | **str** | Specifies the configuration GUIDs, from which test points are created. You can specify several GUIDs. | 
**workitem_ids** | **[str]** | Specifies the work item GUIDs, from which test points are created. You can specify several GUIDs. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


